@@ -1,35 +1,49 @@
-(* $Id: atd_predef.ml 51874 2010-11-16 05:28:46Z martin $ *)
-
 (*
   Table of predefined types.
 *)
 
 open Atd_ast
 
-let list_def : type_def = 
+let list_def : type_def =
   let loc = dummy_loc in
   (
-    loc, 
+    loc,
     ("list", ["a"], []),
     `List (loc, `Tvar (loc, "a"), [])
   )
 
-let option_def : type_def = 
+let option_def : type_def =
   let loc = dummy_loc in
   (
-    loc, 
+    loc,
     ("option", ["a"], []),
     `Option (loc, `Tvar (loc, "a"), [])
   )
 
-let shared_def : type_def = 
+let nullable_def : type_def =
   let loc = dummy_loc in
   (
-    loc, 
+    loc,
+    ("nullable", ["a"], []),
+    `Nullable (loc, `Tvar (loc, "a"), [])
+  )
+
+let shared_def : type_def =
+  let loc = dummy_loc in
+  (
+    loc,
     ("shared", ["a"], []),
     `Shared (loc, `Tvar (loc, "a"), [])
   )
 
+let wrap_def : type_def =
+  let loc = dummy_loc in
+  (
+    loc,
+    ("wrap", ["a"], []),
+    `Wrap (loc, `Tvar (loc, "a"), [])
+  )
+
 
 let list = [
     "unit", 0, None;
@@ -40,7 +54,9 @@ let list = [
     "abstract", 0, None;
     "list", 1, Some list_def;
     "option", 1, Some option_def;
+    "nullable", 1, Some nullable_def;
     "shared", 1, Some shared_def;
+    "wrap", 1, Some wrap_def;
   ]
 
 let make_table () =
