@@ -56,8 +56,10 @@ let parse
   let l =
     List.map (
       fun file ->
-        Atd_util.load_file ~expand ~keep_poly ~xdebug
-          ~inherit_fields ~inherit_variants file
+        fst (
+          Atd_util.load_file ~expand ~keep_poly ~xdebug
+            ~inherit_fields ~inherit_variants file
+        )
     ) files
   in
   let heads, bodies = List.split l in
@@ -132,7 +134,7 @@ let () =
           where the contents are formatted as HTML
           using <p>, <code> and <pre>.
           This is suitable input for \"caml2html -ext html:cat\"
-          which allows to convert ATD files into HTML.";
+          which converts ATD files into HTML.";
 
     "-strip",
     Arg.String (fun s -> strip_sections := split_on_comma s @ !strip_sections),
